@@ -31,10 +31,11 @@
 # delete this exception statement from your version.
 
 
-from gi.repository import Gtk, Gio, GLib, Gdk
+from gi.repository import Gtk, Gio, GLib, Gdk, Notify
 from gettext import gettext as _
 from gnomemusic.window import Window
 from gnomemusic.mpris import MediaPlayer2Service
+from gnomemusic.notification import NotificationManager
 
 
 class Application(Gtk.Application):
@@ -42,7 +43,7 @@ class Application(Gtk.Application):
         Gtk.Application.__init__(self,
                                  application_id='org.gnome.Music',
                                  flags=Gio.ApplicationFlags.FLAGS_NONE)
-        GLib.set_application_name(_('Music'))
+        GLib.set_application_name(_("Music"))
         GLib.set_prgname('gnome-music')
         cssProviderFile = Gio.File.new_for_uri('resource:///org/gnome/Music/application.css')
         cssProvider = Gtk.CssProvider()
@@ -98,13 +99,17 @@ class Application(Gtk.Application):
     def do_startup(self):
         Gtk.Application.do_startup(self)
 
+        Notify.init(_("Music"))
+
         self.build_app_menu()
 
-    def quit(self, action, param):
+    def quit(self, action=None, param=None):
         self._window.destroy()
 
     def do_activate(self):
         if not self._window:
             self._window = Window(self)
             self.service = MediaPlayer2Service(self)
+            self._notifications = NotificationManager(self._window.player)
+
         self._window.present()
