@@ -43,6 +43,7 @@ class MediaPlayer2Service(dbus.service.Object):
         self.app = app
         self.player = app.get_active_window().player
         self.player.connect('current-changed', self._on_current_changed)
+        self.player.connect('thumbnail-updated', self._on_thumbnail_updated)
         self.player.connect('playback-status-changed', self._on_playback_status_changed)
         self.player.connect('repeat-mode-changed', self._on_repeat_mode_changed)
         self.player.connect('volume-changed', self._on_volume_changed)
@@ -109,6 +110,9 @@ class MediaPlayer2Service(dbus.service.Object):
         return metadata
 
     def _on_current_changed(self, player, data=None):
+        if self.player.repeat == RepeatType.SONG:
+            self.Seeked(0)
+
         self.PropertiesChanged(self.MEDIA_PLAYER2_PLAYER_IFACE,
                                {
                                    'Metadata': dbus.Dictionary(self._get_metadata(),
@@ -118,6 +122,14 @@ class MediaPlayer2Service(dbus.service.Object):
                                },
                                [])
 
+    def _on_thumbnail_updated(self, player, path, data=None):
+        self.PropertiesChanged(self.MEDIA_PLAYER2_PLAYER_IFACE,
+                               {
+                                   'Metadata': dbus.Dictionary(self._get_metadata(),
+                                                               signature='sv'),
+                               },
+                               [])
+
     def _on_playback_status_changed(self, data=None):
         self.PropertiesChanged(self.MEDIA_PLAYER2_PLAYER_IFACE,
                                {
@@ -193,7 +205,7 @@ class MediaPlayer2Service(dbus.service.Object):
         elif self.first_song_handler == 0:
             window = self.app.get_active_window()
             window._stack.set_visible_child(window.views[2])
-            model = window.views[2]._model
+            model = window.views[2].filter
             if model.iter_n_children(None):
                 _iter = model.get_iter_first()
                 self._play_first_song(model, model.get_path(_iter), _iter)
