@@ -66,8 +66,8 @@ class ViewContainer(Stack):
     def __init__(self, title, header_bar, selection_toolbar, useStack=False):
         Stack.__init__(self,
                        transition_type=StackTransitionType.CROSSFADE)
-        self._grid = Gtk.Grid(orientation=Gtk.Orientation.VERTICAL)
-        self._iconWidth = -1
+        self._grid = Gtk.Grid(orientation=Gtk.Orientation.HORIZONTAL)
+        self._iconWidth = 128
         self._iconHeight = 128
         self._offset = 0
         self._adjustmentValueId = 0
@@ -90,7 +90,6 @@ class ViewContainer(Stack):
             shadow_type=Gtk.ShadowType.NONE
         )
         self.view.set_view_type(Gd.MainViewType.ICON)
-        self.view.set_model(self._model)
         self.filter = self._model.filter_new(None)
         self.view.set_model(self.filter)
         self.vadjustment = self.view.get_vadjustment()
@@ -243,7 +242,7 @@ class ViewContainer(Stack):
                             [0, 1, 2, 3, 4, 5, 7, 8, 9, 10],
                             [str(item.get_id()), '', title,
                              artist, self._symbolicIcon, item,
-                             -1, icon_name, False, icon_name == self.errorIconName])
+                             0, icon_name, False, icon_name == self.errorIconName])
             GLib.idle_add(self._update_album_art, item, _iter)
 
         GLib.idle_add(add_new_item)
@@ -270,6 +269,7 @@ class ViewContainer(Stack):
             self._model.set_value(
                 _iter, 4,
                 albumArtCache.get_default()._make_icon_frame(icon))
+            self.view.queue_draw()
 
     def _add_list_renderers(self):
         pass
@@ -291,7 +291,7 @@ class Empty(Stack):
         music_folder_path = GLib.get_user_special_dir(GLib.USER_DIRECTORY_MUSIC)
         widget = builder.get_object('container')
         label = builder.get_object('label1')
-        label.set_label(_("No Music found!\n Put some files into the folder %s" %music_folder_path))
+        label.set_label(_("No Music found!\n Put some files into the folder %s") % music_folder_path)
         self.add(widget)
         self.show_all()
 
